TIMSSParameters: TIMSS 2015 4th Grade Math Polytomous Item Parameters.

Description Usage Format Source

Description

A dataset containing multiple sets of polytomous item parameters based on the 2015 TIMSS Math test.

Usage

1

Format

A data frame with 160 rows and 7 columns:

Item

the item

Model

the polytomous model it fits

Step1

the first step difficulty parameter

Difficulty

the difficulty parameter

Step2

the second step difficulty parameter

Discrimination

the item discrimination

Reversed

whether the item step parameters are allowed to be reversed (Step2 < Step1)

https://timss.bc.edu/timss2015/international-database/


AnthonyRaborn/cvIRT documentation built on Jan. 9, 2020, 3:26 a.m.