Description Usage Format Source
A dataset containing multiple sets of polytomous item parameters based on the 2015 TIMSS Math test.
1 |
A data frame with 160 rows and 7 columns:
the item
the polytomous model it fits
the first step difficulty parameter
the difficulty parameter
the second step difficulty parameter
the item discrimination
whether the item step parameters are allowed to be reversed (Step2 < Step1)
https://timss.bc.edu/timss2015/international-database/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.